@@ -198,7 +198,7 @@ class Bunner(MyActor):
                 self.image = "sit" + str(self.direction)
         elif self.state == PlayerState.SPLASH and self.timer > 84:
             # Display appropriate 'splash' animation frame. Note that we use a different technique to display the
-            # 'splat' image – see: comments earlier in this method. The reason two different techniques are used is
+            # 'splat' image - see: comments earlier in this method. The reason two different techniques are used is
             # that the splash image should be drawn on top of other objects, whereas the splat image must be drawn
             # underneath other objects. Since the player is always drawn on top of other objects, changing the player
             # sprite is a suitable method of displaying the splash image.
@@ -283,7 +283,7 @@ class Row(MyActor):
     def check_collision(self, x):
         # Returns the new state the player should be in, based on whether or not the player collided with anything on
         # this road. As this class is the base class for other types of row, this method defines the default behaviour
-        # – i.e. unless a subclass overrides this method, the player can walk around on a row without dying.
+        # - i.e. unless a subclass overrides this method, the player can walk around on a row without dying.
         return PlayerState.ALIVE, 0
 
     def allow_movement(self, x):
@@ -840,7 +840,7 @@ def update():
 
             # Write high score file
             try:
-                with open("high.txt", "w") as file:
+                with open("/var/tmp/high.txt", "w") as file:
                     file.write(str(high_score))
             except:
                 # If an error occurs writing the file, just ignore it and carry on, rather than crashing
@@ -875,6 +875,8 @@ def draw():
 
 # Set up sound system
 try:
+    pygame.mixer.quit()
+    pygame.mixer.init(44100, -16, 2, 512)
     pygame.mixer.set_num_channels(16)
 except:
     # If an error occurs, just ignore it
@@ -882,7 +884,7 @@ except:
 
 # Load high score from file
 try:
-    with open("high.txt", "r") as f:
+    with open("/var/tmp/high.txt", "r") as f:
         high_score = int(f.read())
 except:
     # If opening the file fails (likely because it hasn't yet been created), set high score to 0
