@@ -501,7 +501,7 @@ class Game:
         return 0.001 + (0.0001 * min(100, self.level))
 
     def max_enemies(self):
-        # Maximum number of enemies on-screen at once – increases as you progress through the levels
+        # Maximum number of enemies on-screen at once - increases as you progress through the levels
         return min((self.level + 6) // 2, 8)
 
     def next_level(self):
@@ -763,6 +763,9 @@ def draw():
 
 # Set up sound system and start music
 try:
+    pygame.mixer.quit()
+    pygame.mixer.init(44100, -16, 2, 1024)
+
     music.play("theme")
     music.set_volume(0.3)
 except:
